/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006 by Colin Guthrie <kde@colin.guthr.ie>
 * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2008 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */


// Local includes.
#include "galleries.h"

// Qt includes.
#include <QString>
#include <QWidget>

// KDE includes.
#include <KDebug>
#include <KConfig>
#include <KConfigGroup>
#include <KLocale>
#include <KApplication>


namespace KIPIGalleryExportPlugin
{

Gallery::Gallery()
{
        load();
}


Gallery::~Gallery()
{
}


QString Gallery::name() const
{
    return mName;
}


QString Gallery::url() const
{
    return mUrl;
}


QString Gallery::username() const
{
    return mUsername;
}


QString Gallery::password() const
{
    return mPassword;
}


unsigned int Gallery::version() const
{
    return mVersion;
}


unsigned int Gallery::galleryId() const
{
    return mGalleryId;
}


// -------------------------------------

void Gallery::setName(QString name)
{
    mName = name;
}


void Gallery::setUrl(QString url)
{
    mUrl = url;
}


void Gallery::setUsername(QString username)
{
    mUsername = username;
}


void Gallery::setPassword(QString password)
{
    mPassword = password;
}


void Gallery::setVersion(unsigned int version)
{
    mVersion = version;
}


void Gallery::setGalleryId(unsigned int galleryId)
{
    mGalleryId = galleryId;
}


void Gallery::load()
{
// FIXME: sure we need this??
    static bool bln_loaded = false;
    if (bln_loaded) return;
    bln_loaded = true;

    // read config
    KConfig config("galleryrc");
    KConfigGroup group = config.group("Gallery Settings");

    kWarning( 51000 ) << "Reading data from galleryrc file.." << endl;

    mName = group.readEntry("Name", QString() );
    mUrl = group.readEntry("URL", QString() );
    mUsername = group.readEntry("Username", QString() );
    mVersion = group.readEntry("Version", QString().toInt() );
    mPassword = group.readEntry("Password", QString() );

}



void Gallery::save()
{
    KConfig config("galleryrc");
    KConfigGroup group = config.group("Gallery Settings");

    kWarning( 51000 ) << "Saving data to galleryrc file.." << endl;

    group.writeEntry(QString("Name"), name() );
    group.writeEntry(QString("URL"), url() );
    group.writeEntry(QString("Username"), username() );
    group.writeEntry(QString("Version"), version() );
    group.writeEntry(QString("Password"), password() );

    kWarning( 51000 ) << "syncing.." << endl;
    config.sync();
}


} // end NameSpace
